package com.ruoyi.project.production.mapper;

import java.util.List;
import com.ruoyi.framework.aspectj.lang.annotation.DataScope;
import com.ruoyi.project.production.domain.TLbnhjstj;

/**
 * 能耗管理统计Mapper接口
 *
 * @author ruoyi
 * @date 2020-12-14
 */
public interface TLbnhjstjMapper
{
    /**
     * 查询能耗管理统计
     *
     * @param id 能耗管理统计ID
     * @return 能耗管理统计
     */
    public TLbnhjstj selectTLbnhjstjById(Long id);

    /**
     * 查询能耗管理统计列表
     *
     * @param tLbnhjstj 能耗管理统计
     * @return 能耗管理统计集合
     */
    @DataScope(deptAlias = "d")
    public List<TLbnhjstj> selectTLbnhjstjList(TLbnhjstj tLbnhjstj);

    /**
     * 新增能耗管理统计
     *
     * @param tLbnhjstj 能耗管理统计
     * @return 结果
     */
    public int insertTLbnhjstj(TLbnhjstj tLbnhjstj);

    /**
     * 修改能耗管理统计
     *
     * @param tLbnhjstj 能耗管理统计
     * @return 结果
     */
    public int updateTLbnhjstj(TLbnhjstj tLbnhjstj);

    /**
     * 删除能耗管理统计
     *
     * @param id 能耗管理统计ID
     * @return 结果
     */
    public int deleteTLbnhjstjById(Long id);

    /**
     * 批量删除能耗管理统计
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTLbnhjstjByIds(Long[] ids);
}